/**
 * iisuOSCbridgeSample by Gilles Pinault.
 * This example shows how to receive data from  iisuOSCbridge from Antoine Renuit.
 * iisuOSCbridge makes the bridge between SoftKinetic iisu - 3d camera middleware and OSC
 * - if iisu is not installed yet, go to SoftKinetic.com and download the free version
 * - if the iisuOSCbridge is not installed yet, go to http://iisuoscbridge.blogspot.be/ to download it
 * and find an extensive documentation.
 * - you also need the oscP5 librairie for Processing. Find it there: http://www.sojamo.de/oscP5 
 *
 * This exemple is heavily based on:
 *   oscP5oscArgument by andreas schlegel
 *   example shows how to parse incoming osc messages "by hand".
 *   it is recommended to take a look at oscP5plug for an alternative way to parse messages.
 *   oscP5 website at http://www.sojamo.de/oscP5
 */

import oscP5.*;
import netP5.*;

OscP5 oscP5;
NetAddress myRemoteLocation;

int Status = 0;
PVector HandTip = new PVector (0,0,0);
PVector HandPalm = new PVector (0,0,0);

PShape circle;
 
void setup() {
  size(400,300,P2D);
  frameRate(25);
  /* start oscP5, listening for incoming messages at port 8000 */
  oscP5 = new OscP5(this,8000);

}

void draw() {
  background(0);
  if (Status>0){
    fill(0,255,0);
  }
  else {
    fill(255,0,0);
  }
  ellipseMode(CENTER);
  ellipse(map(HandTip.x, 0.5,-0.5,0,400),map(HandTip.z, 0.5,-0.5,0,300),8,8);
  ellipse(map(HandPalm.x, 0.5,-0.5,0,400),map(HandPalm.z, 0.5,-0.5,0,300),16,16);
}

/* incoming osc message are forwarded to the oscEvent method. */
void oscEvent(OscMessage theOscMessage) {
  //check if this is the message we are looing for
  if(theOscMessage.checkAddrPattern("/Root/Hand1/Status")==true){
    Status = theOscMessage.get(0).intValue();
    println(theOscMessage.addrPattern()+ " : " + Status);
  }
  
  oscReceiveVector(theOscMessage,"/Root/Hand1/Tip", HandTip, true);
  oscReceiveVector(theOscMessage,"/Root/Hand1/Palm", HandPalm, true);
}

//when "iisuOSCbridge" sends a Vector3, it creates three children "/x", "/y" and "/y"
//this function allows to write the three values into a PVector
//the first parameter: "theOscMessage" is ...the Osc message
// the second: "path" is the osc path to the vector
//  the third: "value" is the reference vector that will be overwritten by the function
//  the fourth: "debug" let you choose if you want to output the values to console
void oscReceiveVector(OscMessage theOscMessage,String path,PVector value,boolean debug){
  if(theOscMessage.checkAddrPattern(path+"/x")==true){
    value.x = theOscMessage.get(0).floatValue();
    if (debug){
      println(theOscMessage.addrPattern()+ " : " + value.x);
    }
  }
    if(theOscMessage.checkAddrPattern(path+"/y")==true){
      value.y = theOscMessage.get(0).floatValue();
      if (debug){
        println(theOscMessage.addrPattern()+ " : " + value.y);
      }
  }
    if(theOscMessage.checkAddrPattern(path+"/z")==true){
      value.z =theOscMessage.get(0).floatValue();
      if (debug){
        println(theOscMessage.addrPattern()+ " : " + value.z);
      }
  }
  return;
}
